# generated by datamodel-codegen:
#   filename:  media.json

from __future__ import annotations

from typing import Optional

from pydantic import BaseModel, Extra


class Media(BaseModel):
    """
    Media Info
    """

    class Config:
        extra = Extra.allow

    album_artist: Optional[str] = None
    album_title: Optional[str] = None
    artist: Optional[str] = None
    duration: Optional[float] = None
    is_fast_forward_enabled: Optional[bool] = None
    is_next_enabled: Optional[bool] = None
    is_pause_enabled: Optional[bool] = None
    is_play_enabled: Optional[bool] = None
    is_previous_enabled: Optional[bool] = None
    is_rewind_enabled: Optional[bool] = None
    is_stop_enabled: Optional[bool] = None
    playback_rate: Optional[float] = None
    position: Optional[float] = None
    repeat: Optional[str] = None
    shuffle: Optional[bool] = None
    status: Optional[str] = None
    subtitle: Optional[str] = None
    thumbnail: Optional[str] = None
    title: Optional[str] = None
    track_number: Optional[int] = None
    type: Optional[str] = None
    updated_at: Optional[float] = None
