# generated by datamodel-codegen:
#   filename:  processes.json

from __future__ import annotations

from typing import Optional

from pydantic import BaseModel, Field


class LastUpdated(BaseModel):
    """
    Last updated
    """

    count: float
    processes: float


class Processes(BaseModel):
    """
    Processes
    """

    id: Optional[str] = Field(None, description="Event ID")
    count: float
    processes: list
    last_updated: Optional[LastUpdated] = Field(None, description="Last updated")
